@@ -174,7 +174,7 @@ PYBIND11_MODULE(_qpdf, m)
             if (e.getErrno() != 0) {
                 TemporaryErrnoChange errno_holder(e.getErrno());
                 PyErr_SetFromErrnoWithFilename(
-                    PyExc_OSError, fix_pypy36_const_char(e.getDescription().c_str()));
+                    PyExc_OSError, e.getDescription().c_str());
             } else {
                 exc_main(e.what());
             }
